==> frock-1.1.1.tgz: package/lib/middleware.js <==
'use strict';

function _typeof(obj) { return obj && typeof Symbol !== "undefined" && obj.constructor === Symbol ? "symbol" : typeof obj; }

/**
 * Copyright 2015 Urban Airship Inc. and Contributors. Subject to the LICENSE
 * file at the top-level directory of this distribution and at
 * https://github.com/urbanairship/frock/blob/master/LICENSE
 */
var url = require('url');

module.exports = { utilMiddleware: utilMiddleware, logMiddleware: logMiddleware };

function logMiddleware(frock, log, options) {
  return logRequest;

  function logRequest(req, res, next) {
    logRequestStarted();

    res.on('finish', logRequestFinished);

    next(req, res);

    function logRequestStarted() {
      log.debug(req.method + '[INCOMING] ' + req.url);
    }

    function logRequestFinished() {
      log.info(req.method + '[' + res.statusCode + '] ' + req.url);
    }
  }
}

function utilMiddleware(frock, log, options) {
  return processRequest;

  function processRequest(req, res, next) {
    var parsedUrl = url.parse(req.url, true);

    req.GET = parsedUrl.query || {};

    res.json = json;
    res.e404 = e404;
    res.e400 = e400;
    res.e500 = e500;
    res.error = error;

    next(req, res);

    function json(raw) {
      var status = arguments.length <= 1 || arguments[1] === undefined ? 200 : arguments[1];

      var _ref = arguments.length <= 2 || arguments[2] === undefined ? {} : arguments[2];

      var _ref$contentType = _ref.contentType;
      var contentType = _ref$contentType === undefined ? 'application/json' : _ref$contentType;

      var data = undefined;

      try {
        data = JSON.stringify(raw);
      } catch (e) {
        data = e.toString();
        status = 500;
      }

      res.setHeader('Content-Type', contentType);

      res.statusCode = status;
      res.end(data);
    }

    function _exxx(data, status) {
      if ((typeof data === 'undefined' ? 'undefined' : _typeof(data)) === 'object') {
        return json(data, status);
      }

      if (data && data.toString) {
        data = data.toString();
      }

      res.statusCode = status;
      res.end(data);
    }

    function e400(data) {
      _exxx(data, 400);
    }

    function e404(data) {
      _exxx(data, 404);
    }

    function e500(data) {
      _exxx(data, 500);
    }

    function error(e) {
      var status = arguments.length <= 1 || arguments[1] === undefined ? 500 : arguments[1];

      log.debug(e.stack);

      _exxx(e, status);
    }
  }
}

==> frock-2.0.0.tgz: package/lib/middleware.js <==
'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

/**
 * Copyright 2015 Urban Airship Inc. and Contributors. Subject to the LICENSE
 * file at the top-level directory of this distribution and at
 * https://github.com/urbanairship/frock/blob/master/LICENSE
 */
var url = require('url');

module.exports = { utilMiddleware: utilMiddleware, logMiddleware: logMiddleware };

function logMiddleware(frock, log, options) {
  return logRequest;

  function logRequest(req, res, next) {
    logRequestStarted();

    res.on('finish', logRequestFinished);

    next(req, res);

    function logRequestStarted() {
      log.debug(req.method + '[INCOMING] ' + req.url);
    }

    function logRequestFinished() {
      log.info(req.method + '[' + res.statusCode + '] ' + req.url);
    }
  }
}

function utilMiddleware(frock, log, options) {
  return processRequest;

  function processRequest(req, res, next) {
    var parsedUrl = url.parse(req.url, true);

    req.GET = parsedUrl.query || {};

    res.json = json;
    res.e404 = e404;
    res.e400 = e400;
    res.e500 = e500;
    res.error = error;

    next(req, res);

    function json(raw) {
      var status = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 200;

      var _ref = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {},
          _ref$contentType = _ref.contentType,
          contentType = _ref$contentType === undefined ? 'application/json' : _ref$contentType;

      var data = void 0;

      try {
        data = JSON.stringify(raw);
      } catch (e) {
        data = e.toString();
        status = 500;
      }

      res.setHeader('Content-Type', contentType);

      res.statusCode = status;
      res.end(data);
    }

    function _exxx(data, status) {
      if ((typeof data === 'undefined' ? 'undefined' : _typeof(data)) === 'object') {
        return json(data, status);
      }

      if (data && data.toString) {
        data = data.toString();
      }

      res.statusCode = status;
      res.end(data);
    }

    function e400(data) {
      _exxx(data, 400);
    }

    function e404(data) {
      _exxx(data, 404);
    }

    function e500(data) {
      _exxx(data, 500);
    }

    function error(e) {
      var status = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 500;

      log.debug(e.stack);

      _exxx(e, status);
    }
  }
}
